# Psychometrics


![Build status](https://github.com/tetsuzawa/dxx-py/workflows/Build/badge.svg)
<a href="LICENSE"><img src="http://img.shields.io/badge/license-MIT-blue.svg?style=flat" alt="MIT License"></a>


## Introduction

Psychometrics is a library for psychological measurement experiment.


## Features

The following methods can be used.

- PEST
- BestPEST
- Hybrid



## Installation

```bash
pip install psychometrics
```

## License

[MIT](LICENSE) License

Copyright (c) 2020-present, Tetsu Takizawa and Contributors.